@@ -8,7 +8,7 @@ import json
 from argparse import ArgumentParser, Namespace
 
 from idb.cli import ClientCommand
-from idb.common.types import IdbClient
+from idb.common.types import Client
 
 
 class DylibInstallCommand(ClientCommand):
@@ -24,7 +24,7 @@ class DylibInstallCommand(ClientCommand):
         parser.add_argument("dylib_path", help="Path to the dylib to install", type=str)
         super().add_parser_arguments(parser)
 
-    async def run_with_client(self, args: Namespace, client: IdbClient) -> None:
+    async def run_with_client(self, args: Namespace, client: Client) -> None:
         async for install_response in client.install_dylib(args.dylib_path):
             if install_response.progress != 0.0 and not args.json:
                 print("Installed {install_response.progress}%")
