@@ -8,7 +8,7 @@ import json
 from argparse import ArgumentParser, Namespace
 
 from idb.cli import ClientCommand
-from idb.common.types import IdbClient
+from idb.common.types import Client
 
 
 class FrameworkInstallCommand(ClientCommand):
@@ -26,7 +26,7 @@ class FrameworkInstallCommand(ClientCommand):
         )
         super().add_parser_arguments(parser)
 
-    async def run_with_client(self, args: Namespace, client: IdbClient) -> None:
+    async def run_with_client(self, args: Namespace, client: Client) -> None:
         async for install_response in client.install_framework(args.framework_path):
             if install_response.progress != 0.0 and not args.json:
                 print("Installed {install_response.progress}%")
