@@ -7,7 +7,7 @@
 from argparse import ArgumentParser, Namespace
 
 from idb.cli import ClientCommand
-from idb.common.types import IdbClient
+from idb.common.types import Client
 
 
 class LocationSetCommand(ClientCommand):
@@ -24,5 +24,5 @@ class LocationSetCommand(ClientCommand):
         parser.add_argument("longitude", help="Longitude to set", type=float)
         super().add_parser_arguments(parser)
 
-    async def run_with_client(self, args: Namespace, client: IdbClient) -> None:
+    async def run_with_client(self, args: Namespace, client: Client) -> None:
         await client.set_location(args.latitude, args.longitude)
