@@ -6,6 +6,7 @@
 
 import json
 from argparse import REMAINDER, ArgumentParser, Namespace
+from pathlib import Path
 from typing import Optional, Set
 
 from idb.cli import ClientCommand
@@ -103,8 +104,9 @@ class XctestListTestsCommand(ClientCommand):
     async def run_with_client(self, args: Namespace, client: Client) -> None:
         if args.install:
             await self.install_bundles(args, client)
+        app_path = args.app_path and str(Path(args.app_path).resolve(strict=True))
         tests = await client.list_test_bundle(
-            test_bundle_id=args.test_bundle_id, app_path=args.app_path
+            test_bundle_id=args.test_bundle_id, app_path=app_path
         )
         if args.json:
             print(json.dumps(tests))
@@ -164,6 +166,17 @@ class CommonRunXcTestCommand(ClientCommand):
             "--coverage-output-path",
             help="Outputs coverage information in the llvm json format",
         )
+        parser.add_argument(
+            "--log-directory-path",
+            default=None,
+            type=str,
+            help="Path to save the test logs collected",
+        )
+        parser.add_argument(
+            "--wait-for-debugger",
+            action="store_true",
+            help="Suspend test run process to wait for a debugger to be attached. (Only supported by logic test).",
+        )
         parser.add_argument(
             "--install",
             help="When this option is provided bundle_ids are assumed "
@@ -188,6 +201,11 @@ class CommonRunXcTestCommand(ClientCommand):
         is_ui = args.run == "ui"
         is_logic = args.run == "logic"
 
+        if args.wait_for_debugger and not is_logic:
+            print(
+                "--wait_for_debugger flag is only supported for logic tests. Default to False for app and ui tests."
+            )
+
         formatter = json_format_test_info if args.json else human_format_test_info
         crashed_outside_test_case = False
         async for test_result in client.run_xctest(
@@ -206,6 +224,8 @@ class CommonRunXcTestCommand(ClientCommand):
             report_attachments=args.report_attachments,
             activities_output_path=args.activities_output_path,
             coverage_output_path=args.coverage_output_path,
+            log_directory_path=args.log_directory_path,
+            wait_for_debugger=args.wait_for_debugger,
         ):
             print(formatter(test_result))
             crashed_outside_test_case = (
