@@ -9,6 +9,7 @@ import asyncio
 import concurrent.futures
 import logging
 import os
+import shutil
 import sys
 from typing import List, Optional, Set
 
@@ -92,7 +93,7 @@ from idb.cli.commands.xctest import (
 )
 from idb.cli.commands.xctrace import XctraceRecordCommand
 from idb.common.command import Command, CommandGroup
-from idb.common.types import IdbException, ExitWithCodeException
+from idb.common.types import IdbException, ExitWithCodeException, Compression
 
 
 COROUTINE_DRAIN_TIMEOUT = 2
@@ -105,6 +106,12 @@ logging.basicConfig(
 logger: logging.Logger = logging.getLogger()
 
 
+def get_default_companion_path() -> Optional[str]:
+    if sys.platform != "darwin":
+        return None
+    return shutil.which("idb_companion") or "/usr/local/bin/idb_companion"
+
+
 async def gen_main(cmd_input: Optional[List[str]] = None) -> int:
     # Make sure all files are created with global rw permissions
     os.umask(0o000)
@@ -121,6 +128,15 @@ async def gen_main(cmd_input: Optional[List[str]] = None) -> int:
         default="WARNING",
         help="Set the logging level",
     )
+    parser.add_argument(
+        "--compression",
+        dest="compression",
+        choices=[str(key) for (key, _) in Compression.__members__.items()],
+        default=None,
+        help="Compression algorithm, default: GZIP. "
+        "Compressor should be available at this host. "
+        "Decompressor should be available at the destination site (where IDB companion is hosted)",
+    )
     parser.add_argument(
         "--companion",
         type=str,
@@ -131,7 +147,7 @@ async def gen_main(cmd_input: Optional[List[str]] = None) -> int:
     parser.add_argument(
         "--companion-path",
         type=str,
-        default="/usr/local/bin/idb_companion" if sys.platform == "darwin" else None,
+        default=get_default_companion_path(),
         help="The path to the idb companion binary. This is only valid when running on macOS platforms",
     )
     parser.add_argument(
@@ -143,6 +159,13 @@ async def gen_main(cmd_input: Optional[List[str]] = None) -> int:
         "The reason for this is that idb shouldn't assume there are no tunnels from localhost to a remote host."
         "Can also be set with the IDB_COMPANION_LOCAL environment variable",
     )
+    parser.add_argument(
+        "--companion-tls",
+        action="store_true",
+        default=bool(os.environ.get("IDB_COMPANION_TLS")),
+        help="Will force idb client to use TLS encrypted connection to companion."
+        "Can also be set with the IDB_COMPANION_TLS environment variable",
+    )
     parser.add_argument(
         "--no-prune-dead-companion",
         dest="prune_dead_companion",
