@@ -13,6 +13,7 @@ from unittest.mock import ANY, MagicMock, patch
 
 from idb.cli.main import gen_main as cli_main
 from idb.common.types import (
+    Compression,
     CrashLogQuery,
     DomainSocketAddress,
     HIDButtonType,
@@ -147,8 +148,24 @@ class TestParser(TestCase):
     async def test_install(self) -> None:
         self.client_mock.install = MagicMock(return_value=AsyncGeneratorMock())
         app_path = "testApp.app"
+        compression = None
         await cli_main(cmd_input=["install", app_path])
-        self.client_mock.install.assert_called_once_with(app_path)
+        self.client_mock.install.assert_called_once_with(app_path, compression)
+
+    async def test_install_with_bad_compression(self) -> None:
+        self.client_mock.install = MagicMock(return_value=AsyncGeneratorMock())
+        app_path = "testApp.app"
+        exit_code = await cli_main(
+            cmd_input=["--compression", "PZSTD", "install", app_path]
+        )
+        self.assertEqual(exit_code, 2)
+        self.client_mock.install.assert_not_called()
+
+    async def test_install_with_compression(self) -> None:
+        self.client_mock.install = MagicMock(return_value=AsyncGeneratorMock())
+        app_path = "testApp.app"
+        await cli_main(cmd_input=["--compression", "ZSTD", "install", app_path])
+        self.client_mock.install.assert_called_once_with(app_path, Compression.ZSTD)
 
     async def test_uninstall(self) -> None:
         self.client_mock.uninstall = AsyncMock()
@@ -163,10 +180,15 @@ class TestParser(TestCase):
 
     async def test_list_apps_direct_companion_tcp(self) -> None:
         self.client_mock.list_apps = AsyncMock(return_value=[])
-        await cli_main(cmd_input=["--companion", "thehost:123", "list-apps"])
+        await cli_main(
+            cmd_input=["--companion", "thehost:123", "--companion-tls", "list-apps"]
+        )
         self.client_mock.list_apps.assert_called_once()
         self.client_mock.build.assert_called_once_with(
-            address=TCPAddress(host="thehost", port=123), is_local=False, logger=ANY
+            address=TCPAddress(host="thehost", port=123),
+            is_local=False,
+            logger=ANY,
+            use_tls=True,
         )
 
     async def test_list_apps_direct_companion_uxd(self) -> None:
@@ -174,7 +196,10 @@ class TestParser(TestCase):
         await cli_main(cmd_input=["--companion", "/foo/sock", "list-apps"])
         self.client_mock.list_apps.assert_called_once()
         self.client_mock.build.assert_called_once_with(
-            address=DomainSocketAddress(path="/foo/sock"), is_local=False, logger=ANY
+            address=DomainSocketAddress(path="/foo/sock"),
+            is_local=False,
+            logger=ANY,
+            use_tls=False,
         )
 
     async def test_connect_with_host_and_port(self) -> None:
@@ -429,6 +454,7 @@ class TestParser(TestCase):
         namespace.companion_path = COMPANION_PATH
         namespace.companion = None
         namespace.companion_local = False
+        namespace.compression = None
         namespace.prune_dead_companion = True
         namespace.log_level = "WARNING"
         namespace.log_level_deprecated = None
@@ -450,7 +476,10 @@ class TestParser(TestCase):
         namespace.report_attachments = False
         namespace.activities_output_path = None
         namespace.coverage_output_path = None
+        namespace.log_directory_path = None
+        namespace.wait_for_debugger = False
         namespace.install = False
+        namespace.companion_tls = False
         return namespace
 
     async def test_xctest_run_app(self) -> None:
@@ -531,6 +560,7 @@ class TestParser(TestCase):
             namespace.companion_path = COMPANION_PATH
             namespace.companion = None
             namespace.companion_local = False
+            namespace.compression = None
             namespace.prune_dead_companion = True
             namespace.daemon_port = port
             namespace.daemon_grpc_port = grpc_port
@@ -541,6 +571,7 @@ class TestParser(TestCase):
             namespace.reply_fd = None
             namespace.prefer_ipv6 = False
             namespace.notifier_path = None
+            namespace.companion_tls = False
             mock.assert_called_once_with(namespace)
 
     async def test_terminate(self) -> None:
@@ -558,6 +589,7 @@ class TestParser(TestCase):
             namespace.companion_path = COMPANION_PATH
             namespace.companion = None
             namespace.companion_local = False
+            namespace.compression = None
             namespace.prune_dead_companion = True
             namespace.log_level = "WARNING"
             namespace.log_level_deprecated = None
@@ -565,6 +597,7 @@ class TestParser(TestCase):
             namespace.udid = "1234"
             namespace.json = False
             namespace.log_arguments = []
+            namespace.companion_tls = False
             mock.assert_called_once_with(namespace)
 
     async def test_log_arguments(self) -> None:
@@ -575,6 +608,7 @@ class TestParser(TestCase):
             namespace.companion_path = COMPANION_PATH
             namespace.companion = None
             namespace.companion_local = False
+            namespace.compression = None
             namespace.prune_dead_companion = True
             namespace.log_level = "WARNING"
             namespace.log_level_deprecated = None
@@ -582,6 +616,7 @@ class TestParser(TestCase):
             namespace.udid = None
             namespace.json = False
             namespace.log_arguments = ["--", "--style", "json"]
+            namespace.companion_tls = False
             mock.assert_called_once_with(namespace)
 
     async def test_clear_keychain(self) -> None:
@@ -629,6 +664,7 @@ class TestParser(TestCase):
             namespace.companion_path = COMPANION_PATH
             namespace.companion = None
             namespace.companion_local = False
+            namespace.compression = None
             namespace.prune_dead_companion = True
             namespace.log_level = "WARNING"
             namespace.log_level_deprecated = None
@@ -636,6 +672,7 @@ class TestParser(TestCase):
             namespace.udid = None
             namespace.json = False
             namespace.output_file = output_file
+            namespace.companion_tls = False
             mock.assert_called_once_with(namespace)
 
     async def test_video_stream(self) -> None:
@@ -650,6 +687,7 @@ class TestParser(TestCase):
                     companion=None,
                     companion_path=COMPANION_PATH,
                     companion_local=False,
+                    compression=None,
                     prune_dead_companion=True,
                     log_level="WARNING",
                     format="h264",
@@ -661,6 +699,7 @@ class TestParser(TestCase):
                     udid=None,
                     json=False,
                     output_file=output_file,
+                    companion_tls=False,
                 )
             )
 
