@@ -305,6 +305,7 @@ class HIDSwipe:
     start: Point
     end: Point
     delta: Optional[float]
+    duration: Optional[float]
 
 
 @dataclass(frozen=True)
@@ -336,6 +337,11 @@ class FileContainerType(Enum):
 FileContainer = Optional[Union[str, FileContainerType]]
 
 
+class Compression(Enum):
+    GZIP = 0
+    ZSTD = 1
+
+
 class Companion(ABC):
     @abstractmethod
     async def create(
@@ -450,12 +456,16 @@ class Client(ABC):
         report_attachments: bool = False,
         activities_output_path: Optional[str] = None,
         coverage_output_path: Optional[str] = None,
+        log_directory_path: Optional[str] = None,
+        wait_for_debugger: bool = False,
     ) -> AsyncIterator[TestRunInfo]:
         yield
 
     @abstractmethod
     async def install(
-        self, bundle: Union[str, IO[bytes]]
+        self,
+        bundle: Union[str, IO[bytes]],
+        compression: Optional[Compression] = None,
     ) -> AsyncIterator[InstalledArtifact]:
         yield
 
