@@ -51,6 +51,7 @@ from idb.common.types import (
     Client as ClientBase,
     Companion,
     CompanionInfo,
+    Compression,
     CrashLog,
     CrashLogInfo,
     CrashLogQuery,
@@ -147,7 +148,7 @@ from idb.grpc.xctest import (
     make_request,
     make_results,
     save_attachments,
-    write_result_bundle,
+    untar_into_path,
 )
 from idb.grpc.xctest_log_parser import XCTestLogParser
 from idb.grpc.xctrace import (
@@ -173,6 +174,11 @@ VIDEO_FORMAT_MAP: Dict[VideoFormat, "VideoStreamRequest.Format"] = {
     VideoFormat.MINICAP: VideoStreamRequest.MINICAP,
 }
 
+COMPRESSION_MAP: Dict[Compression, "Payload.Compression"] = {
+    Compression.GZIP: Payload.GZIP,
+    Compression.ZSTD: Payload.ZSTD,
+}
+
 
 def log_and_handle_exceptions(func):  # pyre-ignore
     @functools.wraps(func)
@@ -236,6 +242,7 @@ class Client(ClientBase):
         is_local: Optional[bool] = None,
         exchange_metadata: bool = True,
         extra_metadata: Optional[Dict[str, str]] = None,
+        use_tls: bool = False,
     ) -> AsyncGenerator["Client", None]:
         metadata_to_companion = (
             {
@@ -249,8 +256,16 @@ class Client(ClientBase):
             if exchange_metadata
             else {}
         )
+        ssl_context = plugin.channel_ssl_context() if use_tls else None
+        if use_tls:
+            assert ssl_context is not None
         async with (
-            Channel(host=address.host, port=address.port, loop=asyncio.get_event_loop())
+            Channel(
+                host=address.host,
+                port=address.port,
+                loop=asyncio.get_event_loop(),
+                ssl=ssl_context,
+            )
             if isinstance(address, TCPAddress)
             else Channel(path=address.path, loop=asyncio.get_event_loop())
         ) as channel:
@@ -315,7 +330,10 @@ class Client(ClientBase):
                 yield message.output.decode()
 
     async def _install_to_destination(
-        self, bundle: Bundle, destination: Destination
+        self,
+        bundle: Bundle,
+        destination: Destination,
+        compression: Optional[Compression] = None,
     ) -> AsyncIterator[InstalledArtifact]:
         async with self.stub.install.open() as stream:
             generator = None
@@ -336,7 +354,10 @@ class Client(ClientBase):
                     else:
                         # chunk file from file_path
                         generator = generate_binary_chunks(
-                            path=file_path, destination=destination, logger=self.logger
+                            path=file_path,
+                            destination=destination,
+                            compression=compression,
+                            logger=self.logger,
                         )
 
             else:
@@ -344,6 +365,12 @@ class Client(ClientBase):
                 generator = generate_io_chunks(io=bundle, logger=self.logger)
                 # stream to companion
             await stream.send_message(InstallRequest(destination=destination))
+            if compression is not None:
+                await stream.send_message(
+                    InstallRequest(
+                        payload=Payload(compression=COMPRESSION_MAP[compression])
+                    )
+                )
             async for message in generator:
                 await stream.send_message(message)
             await stream.end()
@@ -549,9 +576,13 @@ class Client(ClientBase):
         return _to_crash_log(response)
 
     @log_and_handle_exceptions
-    async def install(self, bundle: Bundle) -> AsyncIterator[InstalledArtifact]:
+    async def install(
+        self,
+        bundle: Bundle,
+        compression: Optional[Compression] = None,
+    ) -> AsyncIterator[InstalledArtifact]:
         async for response in self._install_to_destination(
-            bundle=bundle, destination=InstallRequest.APP
+            bundle=bundle, destination=InstallRequest.APP, compression=compression
         ):
             yield response
 
@@ -952,6 +983,8 @@ class Client(ClientBase):
         report_attachments: bool = False,
         activities_output_path: Optional[str] = None,
         coverage_output_path: Optional[str] = None,
+        log_directory_path: Optional[str] = None,
+        wait_for_debugger: bool = False,
     ) -> AsyncIterator[TestRunInfo]:
         async with self.stub.xctest_run.open() as stream:
             request = make_request(
@@ -973,6 +1006,8 @@ class Client(ClientBase):
                 ),
                 report_attachments=report_attachments,
                 collect_coverage=coverage_output_path is not None,
+                collect_logs=log_directory_path is not None,
+                wait_for_debugger=wait_for_debugger,
             )
             log_parser = XCTestLogParser()
             await stream.send_message(request)
@@ -991,14 +1026,27 @@ class Client(ClientBase):
                         idb_log_buffer.write(line)
 
                 if result_bundle_path:
-                    await write_result_bundle(
-                        response=response,
+                    await untar_into_path(
+                        payload=response.result_bundle,
+                        description="result bundle",
                         output_path=result_bundle_path,
                         logger=self.logger,
                     )
+                if log_directory_path:
+                    await untar_into_path(
+                        payload=response.log_directory,
+                        description="log directory",
+                        output_path=log_directory_path,
+                        logger=self.logger,
+                    )
                 if response.coverage_json and coverage_output_path:
                     with open(coverage_output_path, "w") as f:
                         f.write(response.coverage_json)
+
+                if wait_for_debugger and response.debugger.pid:
+                    print("Tests waiting for debugger. To debug run:")
+                    print(f"lldb -p {response.debugger.pid}")
+
                 for result in make_results(response, log_parser):
                     if activities_output_path:
                         save_attachments(
